class UserDownloaderConfig:
    DEFAULT_CATEGORIES = ["hot", "new", "random_rising", "rising",
                          "controversial", "top", "gilded"]
    DEFAULT_SORT = "hot"
    DEFAULT_SORT_OPTIONS = ["hot", "new", "top", "controversial"]
    DEFAULT_POST_LIMIT = None
    DEFAULT_COMMENT_LIMIT = None